@@ -130,7 +130,7 @@ public:
      * case a new tab (or the very first view) will be created.
      */
     bool openView(QString mimeType, const QUrl &url, KonqView *childView,
-                  const KonqOpenURLRequest &req = KonqOpenURLRequest::null);
+                  const KonqOpenURLRequest &req = KonqOpenURLRequest::null, QUrl requestedUrl={});
 
 //     bool openView(const QString &mimetype, const QUrl &url, KService::Ptr service);
 
@@ -375,8 +375,13 @@ public Q_SLOTS:
 
     void slotCtrlTabPressed();
 
+#if QT_VERSION_MAJOR < 6
     void slotPopupMenu(const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags flags, const KParts::NavigationExtension::ActionGroupMap &);
     void slotPopupMenu(const QPoint &global, const QUrl &url, mode_t mode, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags f, const KParts::NavigationExtension::ActionGroupMap &);
+#else
+    void slotPopupMenu(const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags flags, const KParts::NavigationExtension::ActionGroupMap &, KonqView*);
+    void slotPopupMenu(const QPoint &global, const QUrl &url, mode_t mode, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags f, const KParts::NavigationExtension::ActionGroupMap &, KonqView*);
+#endif
 
     void slotOpenURLRequest(const QUrl &url, KonqOpenURLRequest &req);
 
