@@ -952,6 +952,7 @@ void KonqView::restoreHistory()
 
     setPartMimeType();
 
+    m_requestedUrl = h.url;
     aboutToOpenURL(h.url);
 
     if (h.reload == false && browserExtension() && historyIndex() > 0) {
@@ -1424,15 +1425,12 @@ void HistoryEntry::saveConfig(KConfigGroup &config, const QString &prefix, const
 {
     if (options & KonqFrameBase::SaveUrls) {
         config.writeEntry(QStringLiteral("Url").prepend(prefix), url.url());
-        qDebug() << "WRITING ENTRY" << url.url();
         config.writeEntry(QStringLiteral("LocationBarURL").prepend(prefix), locationBarURL);
-        qDebug() << "WRITING LOCATION BAR" << locationBarURL;
         config.writeEntry(QStringLiteral("Title").prepend(prefix), title);
         config.writeEntry(QStringLiteral("StrServiceType").prepend(prefix), strServiceType);
         config.writeEntry(QStringLiteral("StrServiceName").prepend(prefix), strServiceName);
     } else if (options & KonqFrameBase::SaveHistoryItems) {
         config.writeEntry(QStringLiteral("Url").prepend(prefix), url.url());
-        qDebug() << "WRITING ENTRY" << url.url();
         config.writeEntry(QStringLiteral("LocationBarURL").prepend(prefix), locationBarURL);
         config.writeEntry(QStringLiteral("LocationBarURL").prepend(prefix), locationBarURL);
         config.writeEntry(QStringLiteral("Title").prepend(prefix), title);
@@ -1552,6 +1550,7 @@ void KonqView::storeDelayedLoadingData(const QString& mimeType, const QString& s
     int historySize = grp.readEntry(keyHistoryItems, 0);
     if (historySize < 1) {
         //Note: this won't really open the URL because the part will be a PlaceholderPart
+        m_requestedUrl = url;
         m_pPart->openUrl(url);
         return;
     }
@@ -1559,8 +1558,9 @@ void KonqView::storeDelayedLoadingData(const QString& mimeType, const QString& s
     loadHistoryConfig(grp, prefix);
     if (!m_lstHistory.isEmpty()) {
         //Note: this won't really open the URL because the part will be a PlaceholderPart
-        QUrl url = m_lstHistory.at(m_lstHistoryIndex)->url;
-        m_pPart->openUrl(url);
+        QUrl histUrl = m_lstHistory.at(m_lstHistoryIndex)->url;
+        m_requestedUrl = histUrl;
+        m_pPart->openUrl(histUrl);
     }
 }
 
